import React, { useState, useRef, useEffect, useMemo, useCallback } from "react";
import { useNavigate } from 'react-router-dom';
import {
    List,
    DatagridConfigurable,
    SearchInput,
    TopToolbar,
    SelectColumnsButton,
    EditButton,
    FilterButton,
    CreateButton,
    ExportButton,
    BulkDeleteButton,
    WrapperField,
    useRecordContext,
    useTranslate,
    useNotify,
    useListContext,
    FunctionField,
    TextField,
    NumberField,
    DateField,
    BooleanField,
    ReferenceField,
    TextInput,
    DateTimeInput,
    DateInput,
    SelectInput,
    NumberInput,
    ReferenceInput,
    ReferenceArrayInput,
    AutocompleteInput,
    DeleteButton,
} from 'react-admin';
import { Box, Typography, Card, Stack } from '@mui/material';
import { styled } from '@mui/material/styles';
import TaskItemLogCreate from "./TaskItemLogCreate";
import TaskItemLogPanel from "./TaskItemLogPanel";
import EmptyData from "../components/EmptyData";
import MyCreateButton from "../components/MyCreateButton";
import MyExportButton from '../components/MyExportButton';
import PageDrawer from "../components/PageDrawer";
import MyField from "../components/MyField";
import { PAGE_DRAWER_WIDTH, OPERATE_MODE, DEFAULT_PAGE_SIZE } from '@/config/setting';
import * as Common from '@/utils/common';

const StyledDatagrid = styled(DatagridConfigurable)(({ theme }) => ({
    '& .css-1vooibu-MuiSvgIcon-root': {
        height: '.9em'
    },
    '& .RaDatagrid-row': {
        cursor: 'auto'
    },
    '& .column-name': {
    },
    '& .opt': {
        width: 200
    },
}));

const filters = [
    <SearchInput source="condition" alwaysOn />,
    <DateInput label='common.time.after' source="timeStart" alwaysOn />,
    <DateInput label='common.time.before' source="timeEnd" alwaysOn />,

    <NumberInput source="taskItemId" label="table.field.taskItemLog.taskItemId" />,
    <NumberInput source="taskId" label="table.field.taskItemLog.taskId" />,
    <NumberInput source="orderId" label="table.field.taskItemLog.orderId" />,
    <TextInput source="orderType" label="table.field.taskItemLog.orderType" />,
    <NumberInput source="orderItemId" label="table.field.taskItemLog.orderItemId" />,
    <NumberInput source="source" label="table.field.taskItemLog.source" />,
    <NumberInput source="matnrId" label="table.field.taskItemLog.matnrId" />,
    <TextInput source="maktx" label="table.field.taskItemLog.maktx" />,
    <TextInput source="matnrCode" label="table.field.taskItemLog.matnrCode" />,
    <TextInput source="trackCode" label="table.field.taskItemLog.trackCode" />,
    <TextInput source="unit" label="table.field.taskItemLog.unit" />,
    <NumberInput source="anfme" label="table.field.taskItemLog.anfme" />,
    <TextInput source="batch" label="table.field.taskItemLog.batch" />,
    <TextInput source="spec" label="table.field.taskItemLog.spec" />,
    <TextInput source="model" label="table.field.taskItemLog.model" />,
    <TextInput source="fieldsIndex" label="table.field.taskItemLog.fieldsIndex" />,

    <TextInput label="common.field.memo" source="memo" />,
    <SelectInput
        label="common.field.status"
        source="status"
        choices={[
            { id: '1', name: 'common.enums.statusTrue' },
            { id: '0', name: 'common.enums.statusFalse' },
        ]}
        resettable
    />,
]

const TaskItemLogList = () => {
    const translate = useTranslate();

    const [createDialog, setCreateDialog] = useState(false);
    const [drawerVal, setDrawerVal] = useState(false);

    return (
        <Box display="flex">
            <List
                sx={{
                    flexGrow: 1,
                    transition: (theme) =>
                        theme.transitions.create(['all'], {
                            duration: theme.transitions.duration.enteringScreen,
                        }),
                    marginRight: !!drawerVal ? `${PAGE_DRAWER_WIDTH}px` : 0,
                }}
                title={"menu.taskItemLog"}
                filters={filters}
                empty={false}
                sort={{ field: "create_time", order: "desc" }}
                actions={(
                    <TopToolbar>
                        <FilterButton />
                        <SelectColumnsButton preferenceKey='taskItemLog' />
                        <MyExportButton />
                    </TopToolbar>
                )}
                perPage={DEFAULT_PAGE_SIZE}
            >
                <StyledDatagrid
                    preferenceKey='taskItemLog'
                    bulkActionButtons={false}
                    rowClick={(id, resource, record) => false}
                    expandSingle={true}
                    omit={['id', 'createTime', 'createBy', 'memo', 'taskId', 'orderId', 'orderItemId', 'matnrId']}
                >
                    <NumberField source="id" />
                    <NumberField source="taskItemId" label="table.field.taskItemLog.taskItemId" />
                    <NumberField source="taskId" label="table.field.taskItemLog.taskId" />
                    <NumberField source="orderId" label="table.field.taskItemLog.orderId" />
                    <TextField source="orderType" label="table.field.taskItemLog.orderType" />
                    <NumberField source="orderItemId" label="table.field.taskItemLog.orderItemId" />
                    <NumberField source="source" label="table.field.taskItemLog.source" />
                    <NumberField source="matnrId" label="table.field.taskItemLog.matnrId" />
                    <TextField source="maktx" label="table.field.taskItemLog.maktx" />
                    <TextField source="matnrCode" label="table.field.taskItemLog.matnrCode" />
                    <TextField source="trackCode" label="table.field.taskItemLog.trackCode" />
                    <TextField source="unit" label="table.field.taskItemLog.unit" />
                    <NumberField source="anfme" label="table.field.taskItemLog.anfme" />
                    <TextField source="batch" label="table.field.taskItemLog.batch" />
                    <TextField source="spec" label="table.field.taskItemLog.spec" />
                    <TextField source="model" label="table.field.taskItemLog.model" />
                    <TextField source="fieldsIndex" label="table.field.taskItemLog.fieldsIndex" />

                    <ReferenceField source="updateBy" label="common.field.updateBy" reference="user" link={false} sortable={false}>
                        <TextField source="nickname" />
                    </ReferenceField>
                    <DateField source="updateTime" label="common.field.updateTime" showTime />
                    <ReferenceField source="createBy" label="common.field.createBy" reference="user" link={false} sortable={false}>
                        <TextField source="nickname" />
                    </ReferenceField>
                    <DateField source="createTime" label="common.field.createTime" showTime />
                    <BooleanField source="statusBool" label="common.field.status" sortable={false} />
                    <TextField source="memo" label="common.field.memo" sortable={false} />
                </StyledDatagrid>
            </List>
            <PageDrawer
                title='TaskItemLog Detail'
                drawerVal={drawerVal}
                setDrawerVal={setDrawerVal}
            >
            </PageDrawer>
        </Box>
    )
}

export default TaskItemLogList;
